==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DateTimeColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { DateTimeColumnDescription } from "./DateTimeColumnDescription";
/**
 * @hidden
 */
var DateTimeColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateTimeColumnDescriptionMetadata, _super);
    function DateTimeColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DateTimeColumnDescriptionMetadata.b = function (a) {
        if (DateTimeColumnDescriptionMetadata.a == null) {
            DateTimeColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DateTimeColumnDescriptionMetadata.c(DateTimeColumnDescriptionMetadata.a);
        }
        if (a.k(DateTimeColumnDescriptionMetadata.a)) {
            return;
        }
        a.ab(DateTimeColumnDescriptionMetadata.a);
    };
    DateTimeColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("DateTimeFormat", "ExportedType:string:DateTimeFormats");
        a.item("DateTimeFormat@names", "DateShort;DateLong;TimeShort;TimeLong;DateTimeShort;DateTimeLong");
        a.item("FormatString", "String");
        a.item("EditorFormatString", "String");
        a.item("FormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
        a.item("FormatOverrideRef", "(w:FormatOverride,wf:FormatOverride)DataRef");
        a.item("ShowTodayButton", "Boolean");
        a.item("EditorType", "ExportedType:string:EditorType");
        a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
        a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
        a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("EditorTextField", "String");
        a.item("EditorValueField", "String");
    };
    DateTimeColumnDescriptionMetadata.d = function (a) {
        DateTimeColumnDescriptionMetadata.b(a);
        a.ad("DateTimeColumn", function () { return new DateTimeColumnDescription(); });
        a.ac("DateTimeColumn", DateTimeColumnDescriptionMetadata.a);
    };
    DateTimeColumnDescriptionMetadata.$t = markType(DateTimeColumnDescriptionMetadata, 'DateTimeColumnDescriptionMetadata');
    DateTimeColumnDescriptionMetadata.a = null;
    return DateTimeColumnDescriptionMetadata;
}(Base));
export { DateTimeColumnDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/DateTimeColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { DateTimeColumnDescription } from "./DateTimeColumnDescription";
/**
 * @hidden
 */
var DateTimeColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateTimeColumnDescriptionMetadata, _super);
    function DateTimeColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DateTimeColumnDescriptionMetadata.b = function (a) {
        if (DateTimeColumnDescriptionMetadata.a == null) {
            DateTimeColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DateTimeColumnDescriptionMetadata.c(DateTimeColumnDescriptionMetadata.a);
        }
        if (a.k(DateTimeColumnDescriptionMetadata.a)) {
            return;
        }
        a.ac(DateTimeColumnDescriptionMetadata.a);
    };
    DateTimeColumnDescriptionMetadata.c = function (a) {
        DataGridColumnDescriptionMetadata.c(a);
        a.item("DateTimeFormat", "ExportedType:string:DateTimeFormats");
        a.item("DateTimeFormat@names", "DateShort;DateLong;TimeShort;TimeLong;DateTimeShort;DateTimeLong");
        a.item("FormatString", "String");
        a.item("EditorFormatString", "String");
        a.item("FormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
        a.item("FormatSpecifiers@mustSetInCode", "WebComponents;Blazor;React;WPF;Angular");
        a.item("FormatOverrideRef", "(w:FormatOverride,wf:FormatOverride)DataRef");
        a.item("ShowTodayButton", "Boolean");
        a.item("EditorType", "ExportedType:string:EditorType");
        a.item("EditorType@names", "Default;Text;Numeric;Date;Combo");
        a.item("EditorDataSourceRef", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)DataRef::object");
        a.item("EditorDataSource", "(w:EditorItemsSource,xam:EditorItemsSource,wf:EditorItemsSource)ExportedType:BaseDataSource:BaseDataSource");
        a.item("EditorTextField", "String");
        a.item("EditorValueField", "String");
    };
    DateTimeColumnDescriptionMetadata.d = function (a) {
        DateTimeColumnDescriptionMetadata.b(a);
        a.ae("DateTimeColumn", function () { return new DateTimeColumnDescription(); });
        a.ad("DateTimeColumn", DateTimeColumnDescriptionMetadata.a);
    };
    DateTimeColumnDescriptionMetadata.$t = markType(DateTimeColumnDescriptionMetadata, 'DateTimeColumnDescriptionMetadata');
    DateTimeColumnDescriptionMetadata.a = null;
    return DateTimeColumnDescriptionMetadata;
}(Base));
export { DateTimeColumnDescriptionMetadata };
